This package aims to uncover the hidden fallacies in the AI/ML models. It is under constant development at both the philosophical level as well as the algorithmic level. While this package is open source, the mathematical concepts underpinning the core algorithm are not. To be more precise, this package calls an API managed by FOYI and therefore **requires a free API subscription**. Please visit our official documentation at https://www.foyi.co.nz/posts/documentation/documentationuncovr/. For updates, please follow us at https://www.linkedin.com/company/foyi/
